function F = goal(GF, C, nx, X, N, bigM, blk)
% goal Create goal constraints
%
% :copyright: 2014 by the California Institute of Technology
% :license: BSD 3-Clause, see LICENSE for details

if ~isempty(GF)
    % Create "goal" constraints
    F = [];
    for i = 1:length(GF)
        nPoly = length(GF{i});   

        H = cell(1, nPoly);
        K = cell(1, nPoly);
        M = cell(1, nPoly);
        for j = 1:nPoly
            [h,k] = double(GF{i}(j));
            H{j} = h;
            K{j} = k;
            M{j} = bigM*ones(length(k), 1);
        end

        % TODO: further vectorize to eliminate 'for' loop
        H = blkdiag(H{:});
        K = vertcat(K{:});
        M = blkdiag(M{:});
        I = kron(ones(nPoly, 1), C);

        assert( blk >= 1 )   
        if blk >= 2
            fprintf('Blocking goal by %i.\n', blk);
        end

        z_vec = [];
        for t = 1:N+1
            if mod(t + blk - 1, blk) == 0
                z = binvar(nPoly, 1);
                z_vec = [z_vec, z];
            end

            F = [F, H*I*X((t-1)*nx+1: t*nx) <= K + M*(1 - z) ];
        end
        % Constraints can be equality if the z variables
        % are not used with any other LTL formula.
        F = [F, sum(z_vec) == 1];
    end
else
    F = [];
end

end
