function fGoal = goalAuto(GF, C, X, N, bigM, s)
% goalAuto Create goal constraints w/ automatic prefix/suffix split
%
% :copyright: 2014 by the California Institute of Technology
% :license: BSD 3-Clause, see LICENSE for details

if ~isempty(GF)
    % Create goal constraints
    fGoal = [];
    for j=1:length(GF)

        numLivePoly = length(GF{j});
        z_goal = binvar((N+1)*numLivePoly, 1);
        th = sdpvar(N+1,1);

        H_list = cell(numLivePoly, 1);
        K_list = cell(numLivePoly, 1);
        M_list = cell(numLivePoly, 1);
        for i=1:numLivePoly
            [H,K] = double(GF{j}(i));
            H = H*C;

            % Create constraints at each time step
            H_list{i} = kron(eye(N+1), H);
            K_list{i} = repmat(K, N+1, 1);
            M_list{i} = kron(eye(N+1), bigM*ones(length(K), 1));
        end
        H_live = vertcat(H_list{:});
        K_live = vertcat(K_list{:});
        M_live = blkdiag(M_list{:});

        P = repmat(eye(N+1), 1, numLivePoly)*z_goal;
        fGoal = [fGoal, H_live*X <= K_live + M_live*(1 - z_goal),...
                        th <= bigM*s, ...
                        th >= -bigM*s, ...
                        th <= P + bigM*(1 - s), ...
                        th >= P - bigM*(1 - s), ...
                        ones(1,N+1)*th == 1];
    end
else
    fGoal = [];
end

end
