function mainLTL()
% mainLTL Solve LTL trajectory optimization problems 
%
% :copyright: 2014 by the California Institute of Technology
% :license: BSD 3-Clause, see LICENSE for details

close all; clc;
yalmip('clear');

%% Set parameters
simult = false;
auto = false;
if simult == true && auto == false
        fprintf('Mode: LTL (simultaneous,fixed) MODERATE\n');
elseif simult == true && auto == true
        fprintf('Mode: LTL (simultaneous,auto) SLOW\n');
else
    fprintf('Mode: LTL (sequential) FAST\n');
end

initParams;


%% Create the environment
ex = 5;
env = envLTL(ex);
obstacles = env.work.unsafe;
plotEnv(env, obstacles);
ops.dim = env.util.dim;


%% Create the LTL specification
ltl = struct();
ltl.G = env.work.safe;
ltl.FG = [];
ltl.F = {env.AP.c};
ltl.GF = {env.AP.a, env.AP.b, env.AP.d, env.AP.e};


%% LTL Motion Planning
fprintf('\nSolving LTL motion planning problem...\n');
normType = 1;

Npre = ceil(N/2);
Nsuf = N - Npre;

if simult  % Simultaneous solution
    [X, U, fSys, sys] = getDyn(model, dt, N, ops);
    J = getCost(model, U, normType);
    fInit = getInit(model, X, sys);

    [prefix, suffix, cost, sol] = getTrajSim(X, U, J, ltl, ...
                                             fSys, fInit, model, sys, options, ...
                                             N, Npre, Nsuf, bigM, auto, blkVar);

    plotTraj(prefix, suffix, model, sys, env.util.dim);

else
    % Sequential solution: suffix first, then prefix.
    % Note: Only solves for a given selection of Nsuf. Can loop over
    % all reasonable Nsuf values if desired.

    %% Suffix
    [X, U, fSys, sys] = getDyn(model, dt, Nsuf, ops);

    fG =  safe(ltl.G, sys.C, sys.nx, X, Nsuf, bigM, blkVar);
    fFG = safe(ltl.FG, sys.C, sys.nx, X, Nsuf, bigM, blkVar);
    fGF = goal(ltl.GF, sys.C, sys.nx, X, Nsuf, bigM, blkVar);

    J = getCost(model, U, normType);

    suffix = getSuffix(X, U, J, fG, fFG, fGF, fSys, sys.nx, model, options);


    %% Prefix
    [X, U, fSys, sys] = getDyn(model, dt, Npre, ops);

    fInit = getInit(model, X, sys);
    fG =  safe(ltl.G, sys.C, sys.nx, X, Npre, bigM, blkVar);
    fF =  goal(ltl.F, sys.C, sys.nx, X, Npre, bigM, blkVar);

    J = getCost(model, U, normType);

    prefix = getPrefix(X, U, J, fG, fF, fSys, fInit, sys.nx, Npre + 1, ...
                       Nsuf, suffix, options);

    plotTraj(prefix, suffix, model, sys, env.util.dim);
end

end
