function mainPt2Pt()
% mainPt2Pt Solve point-to-point (or region) trajectory optimization problems 
%
% :copyright: 2014 by the California Institute of Technology
% :license: BSD 3-Clause, see LICENSE for details

close all; clc;
yalmip('clear');

%% Specify parameters
fprintf('Mode: Point-to-point\n');    
initParams;


%% Create the environment
ex = 3;
env = envPt2Pt(ex);
obstacles = env.work.unsafe;
plotEnv(env, obstacles);
ops.dim = env.util.dim;


%% Specify system dynamics 
[X, U, fSys, sys] = getDyn(model, dt, N, ops);


%% Point-to-point Motion Planning
fprintf('\nStarting point-to-point motion planning...\n');

% Initial and final constraints
fInit = getInit(model, X, sys);
fGoal = getGoal(model, env.AP.goal, X, sys, N);

% Obstacle-avoidance constraints
[fSafe, zSafe] = safe(env.work.safe, sys.C, sys.nx, X, N, bigM, blkVar);

% Cost function
normType = 1;
J = getCost(model, U, normType);

[traj, ctrl, cost, sol] = getTraj(X, U, J, fSafe, fSys, fInit, fGoal, options);

% Plot the resulting trajectory
plotTraj(traj, [], model, sys, env.util.dim);
    
end
