function [X, U, F_sys, sys] = getDyn(model, dt, N, ops)
% getDyn Creates constraints for dynamics
%
% Input: 'model' dynamics
%        'dt' timestep (sec)
%        'N' trajectory length
%        'ops' options
% Output: % Output: 'X' sdpvar for state
%         'U' sdpvar for control
%         'F_sys' dynamic constraints
%         'sys' system info
%
% :copyright: 2014 by the California Institute of Technology
% :license: BSD 3-Clause, see LICENSE for details

if strcmp(model, 'int')
    [X, U, F_sys, sys] = int(dt, N, ops.dim, ops.n_int);

elseif strcmp(model, 'quadrotor')
    [X, U, F_sys, sys] = quadrotor(dt, N, ops.dim); 

elseif strcmp(model, 'car')
    blkMode = 2;
    numTH = 4;
    numV = 3;
    linear = [blkMode, numTH, numV];
    [X, U, F_sys, sys] = car_dubins(dt, N, ops.dim, linear);

else
    error('Invalid system model.')
end 
end