function F_goal = getGoal(model, goal, X, sys, N)
% getGoal Creates constraints for final state
%
% Input: 'model' dynamics
%        'goal' polytope to reach at final step
%        'X' sdpvar for states
%        'sys' system info
%        'N' trajectory length
% Output: 'F_goal' final state constraints
%
% :copyright: 2014 by the California Institute of Technology
% :license: BSD 3-Clause, see LICENSE for details 

assert(1 == length(goal));

X_end = X(sys.nx*N + 1:end);
[H, K] = double(goal);

if strcmp(model, 'int')
    n_int = sys.n_int;
    F_goal = [H*sys.C*X_end <= K, X_end(2:n_int) == 0, ...
              X_end(n_int + 2:2*n_int) == 0];

elseif strcmp(model, 'quadrotor')
    F_goal = [H*sys.C*X_end <= K, X_end(4:end) == 0,];

elseif strcmp(model, 'car')
    F_goal = [H*sys.C*X_end <= K];

else
    error('Invalid system model.');
end

end
