function F_init = getInit(model, X, sys)
% getInit Creates constraints for initial state
%
% Input: 'model' dynamics
%        'X' sdpvar for states
%        'sys' system info
% Output: 'F_init' initial state constraints
%
% :copyright: 2014 by the California Institute of Technology
% :license: BSD 3-Clause, see LICENSE for details

if strcmp(model, 'int')
    x_init = zeros(sys.nx, 1);
    x_init(1) = 0.5;
    x_init(sys.n_int + 1) = 0.5;

    if 3 == sys.dim
        x_init(2*sys.n_int + 1) = 0.25;
    end

elseif strcmp(model, 'quadrotor')
    x_init = [0.5; 0.5; 0.0; zeros(7,1)];

elseif strcmp(model, 'car')
    x_init = [0.5; 0.5; 0];

else
    error('Invalid system model.');
end

F_init = [X(1:sys.nx) == x_init];
    
end
