function F = getLoop(model, X, nx)
% getLoop Creates loop closure constraint
%
% Input: 'model' dynamic model
%        'X' sdpvar of system states
%        'nx' num system states
% Output: 'F' loop closure constraint
%
% :copyright: 2014 by the California Institute of Technology
% :license: BSD 3-Clause, see LICENSE for details

Nsuf = length(X)/nx - 1;

if strcmp(model(1:3), 'car')
    % Car-like cycle constraint, x = (x,y,th,...)
    fprintf('Using car loop constraint.\n');
    F = [X(1) == X(Nsuf*nx+1), X(2) == X(Nsuf*nx+2)];
    
    if nx >= 4
        F = [F, X(4:nx) == X(Nsuf*nx+4:end)];
    end

    % Theta constraints (due to pi == -pi)
    F = [F, X(3) == pi, X(Nsuf*nx+3) == -pi];

else
    F = [X(1:nx) == X(Nsuf*nx+1:end)];
end
end