function options = initSolver(solver, timeLimit, gapLimit, solnLimit, verb)
% initSolver Initializes paramters for solver
%
% Input: solver parameters
% Output: 'options' struct for YALMIP
%
% :copyright: 2014 by the California Institute of Technology
% :license: BSD 3-Clause, see LICENSE for details

if strcmp(solver,'gurobi')
    options = sdpsettings('verbose', verb,'solver', 'gurobi', ...
                          'gurobi.TimeLimit', timeLimit, ...
                          'gurobi.MIPGap', gapLimit, ...
                          'gurobi.SolutionLimit', solnLimit);
                      
elseif strcmp(solver,'cplex')
    options = sdpsettings('verbose', verb, 'solver', 'cplex', ...
                          'cplex.timelimit', timeLimit, ...
                          'cplex.mip.tolerances.mipgap', gapLimit, ...
                          'cplex.mip.limits.solutions', solnLimit);
                      
elseif strcmp(solver,'glpk')
    options = sdpsettings('verbose', verb, 'solver', 'glpk', ...
                          'glpk.tmlim', timeLimit);
end

options.debug = 1;

end
